@@ -44,8 +44,8 @@ def upload_dataset(source_path: str, dataset_name: str, run_id: str = None, vers
 
     else:
         filenames = [os.path.basename(source_path)]
-        full_paths = {os.path.basename(source_path): os.path.abspath(source_path) }
-        num_bytes = os.path.getsize(source_path)
+        full_paths = {os.path.basename(source_path): os.path.abspath(source_path)}
+        num_bytes = [os.path.getsize(source_path)]
     args = (run_id, filenames, full_paths, num_bytes, dataset_name, short_description, version)
     return manager.add_event("add_dataset", args, async_method=False)
 
