@@ -99,6 +99,7 @@ class Run():
                                                     min_cache_flush_delay=5, 
                                                     max_cache_length=25)
         self.log_recorder = None
+        self.logger_name = ''
         self.is_recording_logs = False
         self.logs_buffer = Buffer(push_method=self._push_logs)
         return
@@ -151,28 +152,41 @@ class Run():
         self._read_only = True
 
     @write_method
-    def add_artifacts(self, filepath: str, step: int = None, wait_response: bool = False):
+    @will_be_depreciated('add_artifact')
+    def add_artifacts(self, *args, **kwargs):
+        self.add_artifact(*args, **kwargs)
+
+    @write_method
+    def add_artifact(self, filepath: str, step: int = None, wait_response: bool = False):
         """Log a file as an artifacts. If a file already exists with the name, it will be overwritten.
 
         filepath [str] : Path to the file.
         step [int]: The optional step stamp of the artifacts.
+        wait_response [bool]: Set to true to upload sync. If False, the upload is made in background.
         """
         filename = os.path.basename(filepath)
         num_bytes = os.path.getsize(filepath)
-        content_bytes = open(filepath, "rb")
-        args = (self._id, filename, content_bytes, num_bytes, step)
-        return self.events_manager.add_event("add_file", args, async_method=bool(1-wait_response))
+        args = (self._id, filename, filepath, num_bytes, step)
+        return self.events_manager.add_event("add_artifact", args, async_method=bool(1-wait_response))
 
     @write_method
     def add_mlmodel_usage(self, mlmodel_name: str, version: str = None):
-        """
+        """Manually log that the run is using a specific model. You don't need
+        to use this method if you already use `run.download_mlmodel`.
+
+        mlmodel_name: Name of the mlmodel
+        version: Version of the mlmodel. If None, the latest version is used.
         """
         args = (self._id, mlmodel_name, version, self.project_view['id'])
         self.events_manager.add_event("log_mlmodel", args)
 
     @write_method
     def add_mlmodel_usage_from_dirpath(self, dirpath:str):
-        """Log that this run is using a certain model. 
+        """Manually log that the run is using a specific model, but where 
+        the name and the version are extracted from the path of the mlmodel. You don't need
+        to use this method if you already use `run.download_mlmodel`.
+
+        dirpath: Path to the mlmodel
         """
         meta = mlmodel_info_at_path(dirpath)
         assert meta is not None, f'Could not find the mlmodel at {dirpath}'
@@ -246,14 +260,22 @@ class Run():
 
     @write_method
     def add_dataset_usage(self, dataset_name: str, version: str = None):
-        """
+        """Manually log that the run is using a specific dataset You don't need
+        to use this method if you already use `run.download_dataset`.
+    
+        dataset_name: Name of the dataset
+        version: Version of the dataset. If None, the latest version is used.
+
         """
         args = (self._id, dataset_name, version, self.project_view['id'])
         self.events_manager.add_event("log_dataset", args)
 
     @write_method
     def add_dataset_usage_from_dirpath(self, dirpath:str):
-        """Log that this run is using a certain dataset. 
+        """Manually log that the run is using a specific dataset. You don't need
+        to use this method if you already use `run.download_dataset`.
+
+        dirpath: Path to the mlmodel
         """
         meta = dataset_info_at_path(dirpath)
         assert meta is not None, f'Could not find the dataset at {dirpath}'
@@ -290,10 +312,11 @@ class Run():
 
     @write_method
     @will_be_depreciated('add_tf_model_as_artifact')
-    def add_tf_model(self, model: 'tf.keras.Model', filename: 'str', step: int = None):
-        """Add a tensorflow model as an artifact.
+    def add_tf_model(self, *args, **kwargs):
+        """Add a tensorflow model as an artifact. This method will be depreciated. Use 
+        `add_tf_model_as_artifact`
         """
-        self.add_tf_model_as_artifact(model=model, filename=filename, step=step)
+        self.add_tf_model_as_artifact(*args, **kwargs)
 
     @write_method
     def add_tf_model_as_artifact(self, model: 'tf.keras.Model', filename: str, step: int = None):
@@ -303,18 +326,20 @@ class Run():
         model.save_weights(f"{save_path}/{filename}")
         p = tempfile.mkdtemp()
         shutil.make_archive(f"{p}/{filename}", 'zip', save_path)
-        self.add_artifacts(f"{p}/{filename}.zip", step=step)
+        self.add_artifact(f"{p}/{filename}.zip", step=step)
 
     @write_method
     def add_directory_as_zip_artifact(self, dirpath: str, step: int = None):
+        """Compress a full directory and add the compressed file as an artifact.
+        """
         p = tempfile.mkdtemp()
         filename = os.path.basename(dirpath)
         shutil.make_archive(f"{p}/{filename}", 'zip', root_dir=dirpath)
-        self.add_artifacts(f"{p}/{filename}.zip", step=step)
+        self.add_artifact(f"{p}/{filename}.zip", step=step)
 
     @write_method
     def add_shared_artifact(self, filename: str):
-        """Push an artifact to be shared accross the project.
+        """Push a shared artifact.
         """
         m = SharedArtifactsManager()
         m.push_artifact(filepath=filename, project_id=self.project_view["id"])
@@ -349,7 +374,7 @@ class Run():
     def add_package_versions(self, packages: Optional[dict] =None, with_sys: bool = True, with_python: bool = True, with_git: bool = True):
         """Save the version of the imported packages.
 
-        Use:
+        Usage:
         add_package_versions(globals())
         """
         water = Watermark()
@@ -391,7 +416,7 @@ class Run():
                     One of 'datetime', 'date', None
         """
         filename = get_notebook_file(stamp)
-        self.add_artifacts(filename)
+        self.add_artifact(filename)
 
     @write_method
     def failed(self):
@@ -467,7 +492,7 @@ class Run():
         self.logs_buffer.start(key="logs")
         
         print("Start recording logs.")
-        if (self.log_recorder is None) or self.logger_name!=logger_name:
+        if (self.log_recorder is None) and self.logger_name!=logger_name:
             func = partial(self.logs_buffer.add, key="logs")
             self.log_recorder = LogHandler(func)
             console  = logging.StreamHandler()  
